OSDN Git Service

typo の修正
authorRei FURUKAWA <rei_furukawa@users.sourceforge.jp>
Wed, 21 Apr 2004 23:18:31 +0000 (23:18 +0000)
committerRei FURUKAWA <rei_furukawa@users.sourceforge.jp>
Wed, 21 Apr 2004 23:18:31 +0000 (23:18 +0000)
nkf.c

diff --git a/nkf.c b/nkf.c
index 8730b3e..56ee060 100644 (file)
--- a/nkf.c
+++ b/nkf.c
@@ -55,8 +55,8 @@ static char *Patchlevel =
 ** USAGE:       nkf [flags] [file] 
 **
 ** Flags:
** b    Output is bufferred             (DEFAULT)
** u    Output is unbufferred
 **
 ** t    no operation
 **
@@ -3876,7 +3876,7 @@ usage()
 {
     fprintf(stderr,"USAGE:  nkf(nkf32,wnkf,nkf2) -[flags] [in file] .. [out file for -O flag]\n");
     fprintf(stderr,"Flags:\n");
-    fprintf(stderr,"b,u      Output is bufferred (DEFAULT),Output is unbufferred\n");
+    fprintf(stderr,"b,u      Output is buffered (DEFAULT),Output is unbuffered\n");
 #ifdef DEFAULT_CODE_SJIS
     fprintf(stderr,"j,s,e,w  Outout code is JIS 7 bit, Shift JIS (DEFAULT), AT&T JIS (EUC), UTF-8\n");
 #endif
@@ -55,8 +55,8 @@ static char *Patchlevel =
 **
 ** Flags:
-** b    Output is bufferred             (DEFAULT)
-** u    Output is unbufferred
+** b    Output is buffered             (DEFAULT)
+** u    Output is unbuffered
 **
 ** t    no operation